@@ -369,14 +369,17 @@ class Adapter(BaseResource):
         corresponding LinuxONE machine generations are listed in the notes
         below the table:
 
-        =================  =========================  ===============
-        Adapter type       Machine generations        Maximum domains
-        =================  =========================  ===============
-        Crypto Express 5S  z14 (3) / z13 (1)               85
-        Crypto Express 5S  z14-ZR1 (4) / z13s (2)          40
-        Crypto Express 6S  z14 (3)                         85
-        Crypto Express 6S  z14-ZR1 (4)                     40
-        =================  =========================  ===============
+        =================  ================================  ===============
+        Adapter type       Machine generations               Maximum domains
+        =================  ================================  ===============
+        Crypto Express 5S  z15 (5) / z14 (3) / z13 (1)             85
+        Crypto Express 5S  z15 (6) / z14-ZR1 (4) / z13s (2)        40
+        Crypto Express 6S  z16 (7) / z15 (5) / z14 (3)             85
+        Crypto Express 6S  z15 (6) / z14-ZR1 (4)                   40
+        Crypto Express 7S  z16 (7) / z15 (5)                       85
+        Crypto Express 7S  z15 (6)                                 40
+        Crypto Express 8S  z16 (7)                                 85
+        =================  ================================  ===============
 
         Notes:
 
@@ -384,6 +387,9 @@ class Adapter(BaseResource):
         (2) Supported for z13s and LinuxONE Rockhopper
         (3) Supported for z14 and LinuxONE Emperor II
         (4) Supported for z14-ZR1 and LinuxONE Rockhopper II
+        (5) Supported for z15-T01 and LinuxONE III LT1
+        (6) Supported for z15-T02 and LinuxONE III LT2
+        (7) Supported for z16-A01 and LinuxONE 4
 
         If this adapter is not a crypto adapter, `None` is returned.
 
@@ -610,3 +616,66 @@ class Adapter(BaseResource):
             resource_dict['ports'] = ports
 
         return resource_dict
+
+    @logged_api_call
+    def list_assigned_partitions(self, full_properties=False, filter_args=None):
+        """
+        List the partitions assigned to this adapter.
+
+        This method is not supported for OSA adapters configured as OSM
+        (because those cannot be assigned to partitions).
+
+        Authorization requirements:
+
+        * Object-access permission to this Adapter.
+
+        Parameters:
+
+          full_properties (bool):
+            Controls whether the full set of partition properties should be
+            retrieved, vs. only a short set (uri, name, status).
+
+          filter_args (dict):
+            Filter arguments that narrow the list of returned partitions to
+            those that match the specified filter arguments. For details, see
+            :ref:`Filtering`.
+
+            `None` causes no filtering to happen, i.e. all assigned partitions
+            are returned.
+
+        Returns:
+
+          : A list of :class:`~zhmcclient.Partition` objects.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+        """
+        query_props = ['name', 'status']
+        query_parms, client_filters = divide_filter_args(
+            query_props, filter_args)
+        uri = '{}/operations/get-partitions-assigned-to-adapter{}'.format(
+            self.uri, query_parms)
+
+        result = self.manager.session.get(uri)
+
+        partition_mgr = self.manager.parent.partitions
+        resource_obj_list = []
+        for props in result['partitions-assigned-to-adapter']:
+
+            # pylint: disable=protected-access
+            resource_obj = partition_mgr.resource_class(
+                manager=partition_mgr,
+                uri=props[partition_mgr._uri_prop],
+                name=props.get(partition_mgr._name_prop, None),
+                properties=props)
+
+            if matches_filters(resource_obj, client_filters):
+                resource_obj_list.append(resource_obj)
+                if full_properties:
+                    resource_obj.pull_full_properties()
+
+        return resource_obj_list
