@@ -148,6 +148,11 @@ class Client(object):
 
         This method performs the 'Get Inventory' HMC operation.
 
+        If resources cannot be fully inventoried, the returned list contains
+        items describing the errors. They can be identified by their 'class'
+        property having a value of 'inventory-error'. Note that the presence
+        of such error items does not cause any exceptions to be raised.
+
         Parameters:
 
           resources (:term:`iterable` of :term:`string`):
@@ -248,7 +253,7 @@ class Client(object):
             hmc_definition:
 
               # Internal state:
-              hmc_host: hmc1
+              host: hmc1
               api_version: '2.20'
               metric_group_definitions: [...]
               metric_values: [...]
@@ -299,7 +304,7 @@ class Client(object):
                 "hmc_definition": {
 
                     # Internal state:
-                    "hmc_host": "hmc1",
+                    "host": "hmc1",
                     "api_version": "2.20",
                     "metric_group_definitions": [...],
                     "metric_values": [...],
@@ -329,7 +334,7 @@ class Client(object):
 
             {
                 # Internal state:
-                "hmc_host": "hmc1",
+                "host": "hmc1",
                 "api_version": "2.20",
                 "metric_values": [...],
 
@@ -349,7 +354,7 @@ class Client(object):
         av = self.query_api_version()
         api_version_str = "{}.{}". \
             format(av['api-major-version'], av['api-minor-version'])
-        resource_dict['hmc_host'] = self.session.host
+        resource_dict['host'] = self.session.host
         resource_dict['api_version'] = api_version_str
 
         # Get the current metric values for all metric groups and dump them
