@@ -25,7 +25,8 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, \
+    RC_LDAP_SERVER_DEFINITION
 
 __all__ = ['LdapServerDefinitionManager', 'LdapServerDefinition']
 
@@ -55,20 +56,23 @@ class LdapServerDefinitionManager(BaseManager):
         # If the support for a resource property changes within the set of HMC
         # versions that support this type of resource, this list must be set up
         # for the version of the HMC this session is connected to.
+        # Because this resource has case-insensitive names, this list must
+        # contain the name property.
         query_props = [
             'name',
         ]
 
         super(LdapServerDefinitionManager, self).__init__(
             resource_class=LdapServerDefinition,
-            class_name='ldap-server-definition',
+            class_name=RC_LDAP_SERVER_DEFINITION,
             session=console.manager.session,
             parent=console,
             base_uri='/api/console/ldap-server-definitions',
             oid_prop='element-id',
             uri_prop='element-uri',
             name_prop='name',
-            query_props=query_props)
+            query_props=query_props,
+            case_insensitive_names=True)
 
     @property
     def console(self):
