@@ -209,7 +209,8 @@ class NotificationReceiver(object):
             :term:`HMC API` book.
 
           * message (:term:`JSON object`): Body of the HMC notification,
-            converted into a JSON object.
+            converted into a JSON object. `None` for notifications that
+            have no content in their response body.
 
             The properties of the JSON object vary by notification type.
 
@@ -251,13 +252,16 @@ class NotificationReceiver(object):
                         "Received JMS error from HMC{}".format(details),
                         headers, message)
 
-                try:
-                    msg_obj = json.loads(message)
-                except Exception as exc:
-                    raise NotificationParseError(
-                        "Cannot convert JMS message body to JSON: {}: {}".
-                        format(exc.__class__.__name__, exc),
-                        message)
+                if message:
+                    try:
+                        msg_obj = json.loads(message)
+                    except Exception as exc:
+                        raise NotificationParseError(
+                            "Cannot convert JMS message body to JSON: {}: {}".
+                            format(exc.__class__.__name__, exc),
+                            message)
+                else:
+                    msg_obj = None
 
                 yield headers, msg_obj
 
@@ -267,7 +271,7 @@ class NotificationReceiver(object):
 
                 # Indicate to MessageListener that we are ready for next
                 # notification
-                self._handover_cond.notifyAll()
+                self._handover_cond.notify_all()
 
     @logged_api_call
     def close(self):
@@ -337,7 +341,7 @@ class _NotificationListener(object):
             self._handover_dict['headers'] = None  # terminate receiver
             self._handover_dict['message'] = None
             self._handover_dict['msgtype'] = 'disconnected'
-            self._handover_cond.notifyAll()
+            self._handover_cond.notify_all()
 
     def on_error(self, headers, message):
         """
@@ -367,7 +371,7 @@ class _NotificationListener(object):
             self._handover_dict['headers'] = headers
             self._handover_dict['message'] = message
             self._handover_dict['msgtype'] = 'error'
-            self._handover_cond.notifyAll()
+            self._handover_cond.notify_all()
 
     def on_message(self, headers, message):
         """
@@ -396,4 +400,4 @@ class _NotificationListener(object):
             self._handover_dict['headers'] = headers
             self._handover_dict['message'] = message
             self._handover_dict['msgtype'] = 'message'
-            self._handover_cond.notifyAll()
+            self._handover_cond.notify_all()
