@@ -88,7 +88,8 @@ from ._resource import BaseResource
 from ._storage_volume import StorageVolumeManager
 from ._virtual_storage_resource import VirtualStorageResourceManager
 from ._logging import logged_api_call
-from ._utils import append_query_parms, matches_filters, divide_filter_args
+from ._utils import append_query_parms, matches_filters, divide_filter_args, \
+    RC_STORAGE_GROUP
 
 __all__ = ['StorageGroupManager', 'StorageGroup']
 
@@ -127,7 +128,7 @@ class StorageGroupManager(BaseManager):
 
         super(StorageGroupManager, self).__init__(
             resource_class=StorageGroup,
-            class_name='storage-group',
+            class_name=RC_STORAGE_GROUP,
             session=console.manager.session,
             parent=console,
             base_uri='/api/storage-groups',
@@ -821,3 +822,32 @@ class StorageGroup(BaseResource):
     # TODO: Add support for "Reject Mismatched FCP Storage Volumes" operation
 
     # TODO: Add support for "Get Storage Group Histories" operation
+
+    def dump(self):
+        """
+        Dump this StorageGroup resource with its properties and child
+        resources (recursively) as a resource definition.
+
+        The returned resource definition has the following format::
+
+            {
+                # Resource properties:
+                "properties": {...},
+
+                # Child resources:
+                "storage_volumes": [...],
+            }
+
+        Returns:
+          dict: Resource definition of this resource.
+        """
+
+        # Dump the resource properties
+        resource_dict = super(StorageGroup, self).dump()
+
+        # Dump the child resources
+        storage_volumes = self.storage_volumes.dump()
+        if storage_volumes:
+            resource_dict['storage_volumes'] = storage_volumes
+
+        return resource_dict
