@@ -23,7 +23,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, RC_USER
 
 __all__ = ['UserManager', 'User']
 
@@ -52,6 +52,8 @@ class UserManager(BaseManager):
         # If the support for a resource property changes within the set of HMC
         # versions that support this type of resource, this list must be set up
         # for the version of the HMC this session is connected to.
+        # Because this resource has case-insensitive names, this list must
+        # contain the name property.
         query_props = [
             'name',
             'type',
@@ -59,14 +61,15 @@ class UserManager(BaseManager):
 
         super(UserManager, self).__init__(
             resource_class=User,
-            class_name='user',
+            class_name=RC_USER,
             session=console.manager.session,
             parent=console,
             base_uri='/api/users',
             oid_prop='object-id',
             uri_prop='object-uri',
             name_prop='name',
-            query_props=query_props)
+            query_props=query_props,
+            case_insensitive_names=True)
 
     @property
     def console(self):
